@@ -2018,6 +2018,7 @@ folder_progress_update_cb (GnomeVFSAsyncHandle      *handle,
 					   info->files_total);
 		
 	} else if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
+		
 		if (fcdata->result == GNOME_VFS_OK) {
 			if (fcdata->file_op == FILE_OP_COPY)
 				all_windows_notify_directory_new (fcdata->destination); 
@@ -2057,7 +2058,7 @@ static int
 folder_progress_sync_cb (GnomeVFSXferProgressInfo *info,
 			 gpointer                  data)
 {
-	int ret_val;
+	int ret_val = TRUE;
 
 	if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_OK) {
 		ret_val = TRUE;
@@ -2136,7 +2137,7 @@ folder_copy (GThumbWindow   *window,
 	if (file_op != FILE_OP_DELETE) {
 		if ((src_path == NULL) || (dest_path == NULL))
 			return;
-		if (strncmp (src_path, dest_path, strlen (src_path)) == 0)
+		if (path_in_path (src_path, dest_path))
 			return;
 	}
 
@@ -2199,7 +2200,6 @@ folder_copy (GThumbWindow   *window,
 		char *src_cache;
 		char *dest_cache;
 		char *src_folder_comment;
-		char *dest_folder_comment;
 
 		src_cache = comments_get_comment_dir (src_path, TRUE, TRUE);
 		if (! path_is_dir (src_cache)) {
@@ -2217,9 +2217,13 @@ folder_copy (GThumbWindow   *window,
 			src_list = g_list_append (src_list, 
 						  new_uri_from_path (src_cache));
 
-			if (fcdata->file_op != FILE_OP_DELETE)
+			if (fcdata->file_op != FILE_OP_DELETE) {
+				if (path_is_dir (dest_cache) && !overwrite_all)
+					rmdir_recursive (dest_cache);
+
 				dest_list = g_list_append (dest_list, 
 							   new_uri_from_path (dest_cache));
+			}
 		}
 
 		g_free (src_cache);
@@ -2228,12 +2232,20 @@ folder_copy (GThumbWindow   *window,
 		/**/
 
 		src_folder_comment = comments_get_comment_filename (src_path, TRUE, TRUE);
-		dest_folder_comment = comments_get_comment_filename (dest_path, TRUE, TRUE);
-		src_list = g_list_append (src_list, new_uri_from_path (src_folder_comment));
-		if (fcdata->file_op != FILE_OP_DELETE)
-			dest_list = g_list_append (dest_list, new_uri_from_path (dest_folder_comment));
+
+		if (path_is_file (src_folder_comment)) {
+			char *dest_folder_comment;
+			dest_folder_comment = comments_get_comment_filename (dest_path, TRUE, TRUE);
+			src_list = g_list_append (src_list, new_uri_from_path (src_folder_comment));
+			if (fcdata->file_op != FILE_OP_DELETE) {
+				if (path_is_file (dest_folder_comment))
+					unlink (dest_folder_comment);
+				dest_list = g_list_append (dest_list, new_uri_from_path (dest_folder_comment));
+			}
+			g_free (dest_folder_comment);
+		}
+
 		g_free (src_folder_comment);
-		g_free (dest_folder_comment);
 	}
 
 	xfer_options = GNOME_VFS_XFER_RECURSIVE;
