@@ -33,6 +33,9 @@
 #include <libgnomeui/gnome-dialog.h>
 #include <libgnomeui/gnome-dialog-util.h>
 #include <libgnomeui/gnome-file-entry.h>
+#include <libgnomeui/gnome-icon-theme.h>
+#include <libgnomeui/gnome-icon-lookup.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <gphoto2/gphoto2-context.h>
 #include <gphoto2/gphoto2-camera.h>
 #include <gphoto2/gphoto2-abilities-list.h>
@@ -140,8 +143,8 @@ static void
 destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
-
-	gboolean    thread_done;
+	GThumbWindow *window = data->window;
+	gboolean      thread_done;
 
 	/* Remove check. */
 
@@ -179,6 +182,13 @@ destroy_cb (GtkWidget  *widget,
 	gp_port_info_list_free (data->port_list);
 	g_object_unref (data->gui);
 	g_free (data);
+
+	/**/
+
+	if (ImportPhotos) {
+		ImportPhotos = FALSE;
+		window_close (window);
+	}
 }
 
 
@@ -237,18 +247,16 @@ ctx_progress_update_func (GPContext    *context,
 static gboolean
 valid_mime_type (const char *type)
 {
-	const char *mime_types[] = { GP_MIME_PNG, 
-				     GP_MIME_PGM,
-				     GP_MIME_PPM, 
-				     GP_MIME_PNM, 
-				     GP_MIME_JPEG,
-				     GP_MIME_TIFF,
-				     GP_MIME_BMP };
+	const char *mime_types[] = { "image",
+				     "video",
+				     "audio" };
 	int i;
 
-	for (i = 0; i < G_N_ELEMENTS (mime_types); i++)
-		if (strcasecmp (type, mime_types[i]) == 0)
+	for (i = 0; i < G_N_ELEMENTS (mime_types); i++) {
+		const char *mime_type = mime_types[i];
+		if (strncasecmp (type, mime_type, strlen (mime_type)) == 0)
 			return TRUE;
+	}
 
 	return FALSE;
 }
@@ -277,8 +285,10 @@ get_file_list (DialogData *data,
 			gp_list_get_name (list, i, &name);
 			gp_camera_file_get_info (data->camera, folder, name, &info, data->context);
 			
-			if (valid_mime_type (info.file.type))
-				file_list = g_list_prepend (file_list, g_build_filename (folder, name, NULL));
+			if (valid_mime_type (info.file.type)) {
+				char *filename = g_build_filename (folder, name, NULL);
+				file_list = g_list_prepend (file_list, filename);
+			}
 		}
 	}
 	gp_list_free (list);
@@ -385,10 +395,10 @@ static void
 update_info (DialogData *data)
 {
 	gboolean    update_ui;
-	gfloat      fraction;
+	gfloat      fraction = -0.1;
 	char       *progress_info = NULL;
 	char       *msg_text = NULL;
-	const char *msg_icon;
+	const char *msg_icon = GTK_STOCK_DIALOG_ERROR;
 
 	g_mutex_lock (data->yes_or_no);
 	update_ui = data->update_ui;
@@ -557,6 +567,88 @@ load_images_preview__init (AsyncOperationData *aodata,
 }
 
 
+static int
+get_default_icon_size (GtkWidget *widget)
+{
+        int icon_width, icon_height;
+                                                                                
+        gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
+                                           GTK_ICON_SIZE_DIALOG,
+                                           &icon_width, &icon_height);
+        return MAX (icon_width, icon_height);
+}
+
+
+static GdkPixbuf*
+get_icon_from_mime_type (DialogData *data,
+			 const char *mime_type)
+{
+	GdkPixbuf      *pixbuf = NULL;
+	int             icon_size;
+        GnomeIconTheme *icon_theme = gnome_icon_theme_new ();
+        char           *icon_name;
+        char           *icon_path;
+
+        icon_size = get_default_icon_size (data->dialog);
+        icon_name = gnome_icon_lookup (icon_theme,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       mime_type,
+                                       GNOME_ICON_LOOKUP_FLAGS_NONE,
+                                       NULL);
+	icon_path = gnome_icon_theme_lookup_icon (icon_theme,
+                                                  icon_name,
+                                                  icon_size,
+                                                  NULL,
+                                                  NULL);
+        g_free (icon_name);
+
+	if (icon_path != NULL) {
+		 pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
+                g_free (icon_path);
+	}
+
+	g_object_unref (icon_theme);
+
+	return pixbuf;
+}
+
+
+static const char *
+get_mime_type_from_filename (const char*filename)
+{
+	const char *result;
+
+	char *n1 = g_filename_to_utf8 (filename, -1, 0, 0, 0);
+	char *n2 = g_utf8_strdown (n1, -1);
+	char *n3 = g_filename_from_utf8 (n2, -1, 0, 0, 0);
+	result = gnome_vfs_mime_type_from_name_or_default (n3, NULL);
+	g_free (n3);
+	g_free (n2);
+	g_free (n1);
+
+	return result;
+}
+
+
+static GdkPixbuf*
+get_mime_type_icon (DialogData *data,
+		    const char *filename)
+{
+	GdkPixbuf  *pixbuf = NULL;
+	const char *mime_type;
+
+	mime_type = get_mime_type_from_filename (filename);
+	pixbuf = get_icon_from_mime_type (data, mime_type);
+	if (pixbuf == NULL)
+		pixbuf = get_icon_from_mime_type (data, "image/*");
+
+	return pixbuf;
+}
+
+
 static void 
 load_images_preview__step (AsyncOperationData *aodata, 
 			   DialogData         *data)
@@ -585,6 +677,9 @@ load_images_preview__step (AsyncOperationData *aodata,
 		FileData  *fdata;
 		
 		pixbuf = gdk_pixbuf_new_from_file (tmp_filename, NULL);
+		if (pixbuf == NULL) 
+			pixbuf = get_mime_type_icon (data, camera_filename);
+
 		width = gdk_pixbuf_get_width (pixbuf);
 		height = gdk_pixbuf_get_height (pixbuf);
 		
@@ -603,7 +698,7 @@ load_images_preview__step (AsyncOperationData *aodata,
 		fdata = file_data_new (camera_path, NULL);
 		gth_image_list_append_with_data (GTH_IMAGE_LIST (data->image_list),
 						 pixbuf,
-						 NULL,
+						 camera_filename,
 						 NULL,
 						 fdata);
 		g_object_unref (pixbuf);
@@ -627,7 +722,7 @@ load_images_preview__done (AsyncOperationData *aodata,
 static void
 load_images_preview (DialogData *data)
 {
-	GList              *file_list, *scan;
+	GList              *file_list;
 	gboolean            error;
 	AsyncOperationData *aodata;
 
@@ -682,7 +777,7 @@ set_camera_model (DialogData *data,
 	if ((model == NULL) || (port == NULL)) {
 		data->camera_setted = FALSE;
 		gtk_widget_hide (data->import_preview_box);
-		_gtk_label_set_locale_text (GTK_LABEL (data->camera_model_label), _("No camera detected"));
+		gtk_label_set_text (GTK_LABEL (data->camera_model_label), _("No camera detected"));
 		gtk_image_set_from_pixbuf (GTK_IMAGE (data->progress_camera_image), data->no_camera_pixbuf);
 		return;
 	}
@@ -716,8 +811,8 @@ set_camera_model (DialogData *data,
 		display_error_dialog (data, 
 				      _("Could not import photos"),  
 				      gp_result_as_string (r));
-		_gtk_label_set_locale_text (GTK_LABEL (data->camera_model_label), 
-					    _("No camera detected"));
+		gtk_label_set_text (GTK_LABEL (data->camera_model_label), 
+				    _("No camera detected"));
 		gtk_image_set_from_pixbuf (GTK_IMAGE (data->progress_camera_image), 
 					   data->no_camera_pixbuf);
 	}
@@ -900,10 +995,11 @@ get_folder_name (DialogData *data)
 
 		time (&now);
 		tm = localtime (&now);
-		strftime (time_txt, 50, "%Y-%m-%d--%H:%M:%S", tm);
+		strftime (time_txt, 50, "%Y-%m-%d--%H.%M.%S", tm);
 	
 		film_name = g_strdup (time_txt);
-	}
+	} else
+		eel_gconf_set_path (PREF_PHOTO_IMPORT_FILM, film_name);
 
 	path = g_build_filename (destination, film_name, NULL);
 	g_free (film_name);
@@ -1059,21 +1155,6 @@ add_film_keyword (const char *folder)
 }
 
 
-static void
-cancel_clicked_cb (GtkButton  *button,
-		   DialogData *data)
-{
-	GThumbWindow *window = data->window;
-
-	gtk_widget_destroy (data->dialog);
-
-	if (ImportPhotos) {
-		ImportPhotos = FALSE;
-		window_close (window);
-	}
-}
-
-
 static void 
 delete_images__step (AsyncOperationData *aodata, 
 		     DialogData         *data)
@@ -1165,9 +1246,7 @@ static void
 ok_clicked_cb (GtkButton  *button,
 	       DialogData *data)
 {
-	GThumbWindow       *window = data->window;
 	GList              *file_list = NULL, *scan;
-	int                 n = 1;
 	GList              *sel_list;
 	gboolean            error;
 	AsyncOperationData *aodata;
@@ -1362,6 +1441,8 @@ load_abilities_thread (void *thread_data)
 	g_mutex_unlock (data->yes_or_no);
 
 	g_thread_exit (NULL);
+
+	return NULL;
 }
 
 
@@ -1404,7 +1485,7 @@ start_operation (DialogData    *data,
 		 GthImporterOp  operation)
 {
 	if (data->check_id != 0)
-		g_remove_source (data->check_id);
+		g_source_remove (data->check_id);
 
 	g_mutex_lock (data->yes_or_no);
 	data->thread_done = FALSE;
@@ -1423,6 +1504,7 @@ dlg_photo_importer (GThumbWindow *window)
 	GtkWidget    *btn_ok, *btn_cancel;
 	GdkPixbuf    *mute_pixbuf;
 	char         *default_path;
+	char         *default_film_name;
 
 	data = g_new0 (DialogData, 1);
 	data->window = window;
@@ -1483,6 +1565,7 @@ dlg_photo_importer (GThumbWindow *window)
 	btn_cancel = glade_xml_get_widget (data->gui, "import_cancelbutton");
 
 	data->image_list = gth_image_list_new (THUMB_SIZE + THUMB_BORDER);
+	gth_image_list_set_view_mode (GTH_IMAGE_LIST (data->image_list), GTH_VIEW_MODE_LABEL);
 	gtk_widget_show (data->image_list);
 	gtk_container_add (GTK_CONTAINER (data->import_preview_scrolledwindow), data->image_list);
 
@@ -1520,22 +1603,26 @@ dlg_photo_importer (GThumbWindow *window)
 	_gtk_entry_set_filename_text (GTK_ENTRY (data->destination_entry), default_path);
 	g_free (default_path);
 
+	default_film_name = eel_gconf_get_path (PREF_PHOTO_IMPORT_FILM, "");
+	_gtk_entry_set_filename_text (GTK_ENTRY (data->film_entry), default_film_name);
+	g_free (default_film_name);
+
 	task_terminated (data);
 
 	/* Set the signals handlers. */
 
 	g_signal_connect (G_OBJECT (data->dialog), 
 			  "destroy",
-			  G_CALLBACK (cancel_clicked_cb),
+			  G_CALLBACK (destroy_cb),
 			  data);
 	g_signal_connect (G_OBJECT (btn_ok), 
 			  "clicked",
 			  G_CALLBACK (ok_clicked_cb),
 			  data);
-	g_signal_connect (G_OBJECT (btn_cancel), 
-			  "clicked",
-			  G_CALLBACK (cancel_clicked_cb),
-			  data);
+	g_signal_connect_swapped (G_OBJECT (btn_cancel), 
+				  "clicked",
+				  G_CALLBACK (gtk_widget_destroy),
+				  G_OBJECT (data->dialog));
 	g_signal_connect (G_OBJECT (data->select_model_button), 
 			  "clicked",
 			  G_CALLBACK (dlg_select_camera_model_cb),
